summaryrefslogtreecommitdiff
path: root/nuttx/configs/twr-k60n512/src/up_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/twr-k60n512/src/up_buttons.c')
-rw-r--r--nuttx/configs/twr-k60n512/src/up_buttons.c16
1 files changed, 9 insertions, 7 deletions
diff --git a/nuttx/configs/twr-k60n512/src/up_buttons.c b/nuttx/configs/twr-k60n512/src/up_buttons.c
index 5b449dbe8..c836efee3 100644
--- a/nuttx/configs/twr-k60n512/src/up_buttons.c
+++ b/nuttx/configs/twr-k60n512/src/up_buttons.c
@@ -1,7 +1,7 @@
/****************************************************************************
* configs/twr-k60n512/src/up_buttons.c
*
- * Copyright (C) 2011 Gregory Nutt. All rights reserved.
+ * Copyright (C) 2011, 2014 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
*
* Redistribution and use in source and binary forms, with or without
@@ -41,7 +41,9 @@
#include <stdint.h>
+#include <nuttx/arch.h>
#include <arch/board/board.h>
+
#include "twrk60-internal.h"
#ifdef CONFIG_ARCH_BUTTONS
@@ -68,17 +70,17 @@
****************************************************************************/
/****************************************************************************
- * Name: up_buttoninit
+ * Name: board_button_initialize
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
-void up_buttoninit(void)
+void board_button_initialize(void)
{
/* Configure the two buttons as inputs */
@@ -111,12 +113,12 @@ uint8_t up_buttons(void)
* Button support.
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After up_buttoninit() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
@@ -152,7 +154,7 @@ xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
}
/* The button has already been configured as an interrupting input (by
- * up_buttoninit() above).
+ * board_button_initialize() above).
*
* Attach the new button handler.
*/
@@ -68,17 +70,17 @@
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -111,12 +113,12 @@ uint8_t up_buttons(void)
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -111,12 +113,12 @@ uint8_t up_buttons(void)
* handlers.
*
- * After up_buttoninit() has been called, up_buttons() may be called to
+ * After board_button_initialize() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT